//Copyright 2018 Huawei Technologies Co.,Ltd.

#import <Foundation/Foundation.h>
@protocol UploadVodDelegate <NSObject>
/***
 功能：回调上传进度
 回调参数：prograss 上传进度(范围[0.0,1.0]),当prograss为1.0时，当前文件上传完成,必须实现
 ***/
@required
- (void)prograssCallback:(float)prograss;

/***
 功能：回调错误信息
 回调参数：errorInfo 回调的错误信息，具体信息请到华为云OBS和点播错误码中查找，可选择实现
 ***/
@optional
- (void)errorCallback:(NSDictionary*_Nullable)errorInfo;
@end


@interface vodUploadLib : NSObject
/***
 代理，必须实现
 ***/
@property (nullable, nonatomic, strong) id<UploadVodDelegate> delegateUploadVod;

/***
 功能：初始化
 参数：endPoint 点播服务节点地址，如点播服务的Endpoint当前为“vod.cn-north-1.myhuaweicloud.com”
 AK、SK、token 临时AK、SK、token，临时AK、SK、token需要由租户服务端调用服务端SDK获取
 g_bucketName 媒资所在的桶名
 g_objectKey 媒资所在的ObjectKey
 g_bucketName、g_objectKey 需要服务端调用创建媒资接口后获得并返回给客户端，详情需要参考点播服务端的创建媒资接口
 projectId 用户项目编号ProjectId，查看项目ID参考 "查看项目ID"章节
 ***/
- (instancetype _Nullable )initWithEndPoint:(NSString*_Nullable)endPoint
                                         SK:(NSString*_Nullable)SK
                                         AK:(NSString*_Nullable)AK
                                 bucketName:(NSString*_Nullable)bucketName
                                  objectKey:(NSString*_Nullable)objectKey
                                  projectId:(NSString*_Nullable)projectId
                                      token:(NSString*_Nullable)token;
/***
 功能：设置每段大小，可选择设置
 参数：partSize 段大小(注意段大小设置范围必须是[5，5000],默认为5)
 ***/
-(void)setPartSize :(int)partSize;

/***
 功能：设置上传线程数，可选择设置
 参数：maxConcurrentUploadRequestCount 上传一个文件最多可以几个段同时上传(注意线程数设置范围建议[1,5],默认为3)
 ***/
-(void)setMaxConcurrentUploadRequestCount :(int)maxConcurrentUploadRequestCount;

/***
 功能：开始上传
 参数：filePath 上传文件路径
 ***/
-(void)startUpload :(NSString*_Nullable)filePath;
@end


